@@ -3,9 +3,11 @@
 # This file is part of gunicorn released under the MIT license. 
 # See the NOTICE for more information.
 
+
 import ctypes
 import fcntl
 import os
+import pkg_resources
 import resource
 import socket
 import textwrap
@@ -27,6 +29,11 @@ weekdayname = ['Mon', 'Tue', 'Wed', 'Thu', 'Fri', 'Sat', 'Sun']
 monthname = [None,
              'Jan', 'Feb', 'Mar', 'Apr', 'May', 'Jun',
              'Jul', 'Aug', 'Sep', 'Oct', 'Nov', 'Dec']
+
+hop_headers = set("""
+    connection keep-alive proxy-authenticate proxy-authorization
+    te trailers transfer-encoding upgrade
+    """.split())
              
 try:
     from setproctitle import setproctitle
@@ -35,7 +42,28 @@ try:
 except ImportError:
     def _setproctitle(title):
         return
-             
+
+def load_worker_class(uri):
+    if uri.startswith("egg:"):
+        # uses entry points
+        entry_str = uri.split("egg:")[1]
+        try:
+            dist, name = entry_str.rsplit("#",1)
+        except ValueError:
+            dist = entry_str
+            name = "sync"
+
+        return pkg_resources.load_entry_point(dist, "gunicorn.workers", name)
+    else:
+        components = uri.split('.')
+        if len(components) == 1:
+            raise RuntimeError("arbiter uri invalid")
+        klass = components.pop(-1)
+        mod = __import__('.'.join(components))
+        for comp in components[1:]:
+            mod = getattr(mod, comp)
+        return getattr(mod, klass)
+
 def set_owner_process(uid,gid):
     """ set user and group of workers processes """
     if gid:
@@ -76,8 +104,9 @@ def get_maxfd():
     return maxfd
 
 def close_on_exec(fd):
-    flags = fcntl.fcntl(fd, fcntl.F_GETFD) | fcntl.FD_CLOEXEC
-    fcntl.fcntl(fd, fcntl.F_SETFL, flags)
+    flags = fcntl.fcntl(fd, fcntl.F_GETFD)
+    flags |= fcntl.FD_CLOEXEC
+    fcntl.fcntl(fd, fcntl.F_SETFD, flags)
     
 def set_non_blocking(fd):
     flags = fcntl.fcntl(fd, fcntl.F_GETFL) | os.O_NONBLOCK
@@ -177,3 +206,6 @@ def to_bytestring(s):
         return s.encode('utf-8')
     else:
         return s
+
+def is_hoppish(header):
+    return header.lower().strip() in hop_headers
\ No newline at end of file
