@@ -6,20 +6,22 @@
 
 import array
 import os
+from StringIO import StringIO
 import tempfile
 
 dirname = os.path.dirname(__file__)
 
 from gunicorn.http.parser import Parser
 from gunicorn.http.request import Request
+from gunicorn.config import Config
 
 def data_source(fname):
+    buf = StringIO()
     with open(fname) as handle:
-        lines = []
         for line in handle:
             line = line.rstrip("\n").replace("\\r\\n", "\r\n")
-            lines.append(line)
-        return "".join(lines)
+            buf.write(line)
+        return buf
 
 class request(object):
     def __init__(self, name):
@@ -35,10 +37,10 @@ class request(object):
         
 class FakeSocket(object):
     
-    def __init__(self, data=""):
+    def __init__(self, data):
         self.tmp = tempfile.TemporaryFile()
         if data:
-            self.tmp.write(data)
+            self.tmp.write(data.getvalue())
             self.tmp.flush()
             self.tmp.seek(0)
 
@@ -73,7 +75,7 @@ class http_request(object):
     def __call__(self, func):
         def run():
             fsock = FakeSocket(data_source(self.fname))
-            req = Request(fsock, ('127.0.0.1', 6000), ('127.0.0.1', 8000))
+            req = Request(fsock, ('127.0.0.1', 6000), ('127.0.0.1', 8000), Config({}))
             func(req)
         run.func_name = func.func_name
         return run
